pub struct CreateServerScheduleStepOptions {
pub schedule_uuid: Uuid,
pub action: ScheduleActionInner,
pub order: i16,
}Fields
schedule_uuid: Uuidaction: ScheduleActionInnerorder: i16Trait Implementations
Sourceimpl ComposeSchema for CreateServerScheduleStepOptions
impl ComposeSchema for CreateServerScheduleStepOptions
Sourceimpl<'de> Deserialize<'de> for CreateServerScheduleStepOptions
impl<'de> Deserialize<'de> for CreateServerScheduleStepOptions
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl ToSchema for CreateServerScheduleStepOptions
impl ToSchema for CreateServerScheduleStepOptions
Sourceimpl Validate for CreateServerScheduleStepOptions
impl Validate for CreateServerScheduleStepOptions
Sourcefn validate_into(
&self,
__garde_user_ctx: &Self::Context,
__garde_path: &mut dyn FnMut() -> Path,
__garde_report: &mut Report,
)
fn validate_into( &self, __garde_user_ctx: &Self::Context, __garde_path: &mut dyn FnMut() -> Path, __garde_report: &mut Report, )
Validates
Self, aggregating all validation errors into Report.fn validate(&self) -> Result<(), Report>where
Self::Context: Default,
fn validate(&self) -> Result<(), Report>where
Self::Context: Default,
Validates
Self, returning an Err with an aggregate of all errors if
the validation failed. Read morefn validate_with(&self, ctx: &Self::Context) -> Result<(), Report>
fn validate_with(&self, ctx: &Self::Context) -> Result<(), Report>
Validates
Self, returning an Err with an aggregate of all errors if
the validation failed. Read moreAuto Trait Implementations
impl Freeze for CreateServerScheduleStepOptions
impl RefUnwindSafe for CreateServerScheduleStepOptions
impl Send for CreateServerScheduleStepOptions
impl Sync for CreateServerScheduleStepOptions
impl Unpin for CreateServerScheduleStepOptions
impl UnwindSafe for CreateServerScheduleStepOptions