pub struct ExportedServerScheduleStep {
pub action: ScheduleActionInner,
pub order: i16,
}Fields
action: ScheduleActionInnerorder: i16Trait Implementations
Sourceimpl ComposeSchema for ExportedServerScheduleStep
impl ComposeSchema for ExportedServerScheduleStep
Sourceimpl<'de> Deserialize<'de> for ExportedServerScheduleStep
impl<'de> Deserialize<'de> for ExportedServerScheduleStep
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl ToSchema for ExportedServerScheduleStep
impl ToSchema for ExportedServerScheduleStep
Sourceimpl Validate for ExportedServerScheduleStep
impl Validate for ExportedServerScheduleStep
Sourcefn validate_into(
&self,
__garde_user_ctx: &Self::Context,
__garde_path: &mut dyn FnMut() -> Path,
__garde_report: &mut Report,
)
fn validate_into( &self, __garde_user_ctx: &Self::Context, __garde_path: &mut dyn FnMut() -> Path, __garde_report: &mut Report, )
Validates
Self, aggregating all validation errors into Report.fn validate(&self) -> Result<(), Report>where
Self::Context: Default,
fn validate(&self) -> Result<(), Report>where
Self::Context: Default,
Validates
Self, returning an Err with an aggregate of all errors if
the validation failed. Read morefn validate_with(&self, ctx: &Self::Context) -> Result<(), Report>
fn validate_with(&self, ctx: &Self::Context) -> Result<(), Report>
Validates
Self, returning an Err with an aggregate of all errors if
the validation failed. Read moreAuto Trait Implementations
impl Freeze for ExportedServerScheduleStep
impl RefUnwindSafe for ExportedServerScheduleStep
impl Send for ExportedServerScheduleStep
impl Sync for ExportedServerScheduleStep
impl Unpin for ExportedServerScheduleStep
impl UnwindSafe for ExportedServerScheduleStep